==> nextcloud-15.0.3.zip: nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "动态",
    "An error occurred while loading activities" : "在当前活动加载中出现了一个错误。",
    "No activity yet" : "暂无动态",
    "Load more activities" : "加载更多动态",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "{name} (invisible)" : "{name} (不可见)",
    "{name} (restricted)" : "{name} (受限的)",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和分享之类的事件",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "打开文件",
    "Personal activity feed for %s" : "%s 的个人动态 Feed",
    "Your feed URL is invalid" : "您输入的Feed链接无效",
    "Your settings have been updated." : "您的设置已更新。",
    "Settings have been updated." : "设置已更新。",
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "\"remote user\"" : "远程用户",
    "Activity notification for %s" : "%s 的动态通知",
    "Hello %s" : "您好%s",
    "Hello %s," : "%s 您好，",
    "There was some activity at %s" : "在 %s 里有一些动态",
    "_and %n more _::_and %n more _" : ["更多 %n 项"],
    ", " : "，",
    "%s and %s" : "%s 和 %s",
    "Mail" : "邮件",
    "Stream" : "流",
    "This application enables users to view actions related to their files in Nextcloud." : "本应用可以让用户们查看和他们在Nextcloud上的文件相关的活动。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "本应用能够让用户查看与他们在Nextcloud中的文件相关的活动。\n\t\t一旦启用，用户将看到在他们的应用菜单中出现了一个名为”动态“的新图标.\n\t\t点击后会出现一个页面让用户跟踪文件的动态，包括新增文件、删除文件、移动、重命名、修改和共享。\n\t\t用户可以在个人的菜单中指定单独的动态设置。\n\t\t可以设置要记录的活动类型，以及是否用户看到自己的活动、\n\t\t是否只能在线查看、是否定期收到电子邮件摘要。\n\t\t 更多信息可以在动态文档中进行查看。",
    "Activity feed" : "动态 Feed",
    "Send activity emails" : "发送动态电子邮件",
    "Default settings" : "默认设置",
    "Configure the default activity settings for new users." : "为新用户设置默认的活动配置",
    "List your own actions in the stream" : "在流里面列出您自己的行为",
    "Notify about your own actions via email" : "通过邮件通知您自己的动态",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send emails:" : "发送邮件：",
    "As soon as possible" : "尽快",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "选择您想收到哪些活动的通知邮件，以及哪些活动在应用中显示。",
    "Choose which activities you want to see in your stream." : "选择您要在流中看到哪些活动。",
    "Settings" : "设置",
    "Enable RSS feed" : "启用 RSS 源",
    "RSS feed" : "RSS 源",
    "No more events to load" : "已无更多事件",
    "Files" : "文件",
    "Activities" : "动态",
    "Home" : "主页",
    "Activity notification" : "动态通知"
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.6.zip: nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "动态",
    "An error occurred while loading activities" : "加载动态时出现了一个错误",
    "No activity yet" : "暂无动态",
    "Load more activities" : "加载更多动态",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "{name} (invisible)" : "{name} (不可见)",
    "{name} (restricted)" : "{name} (受限的)",
    "Home" : "主页",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和共享之类的事件",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "打开文件",
    "Personal activity feed for %s" : "%s 的个人活动订阅源",
    "Your feed URL is invalid" : "您的订阅源地址无效",
    "Your settings have been updated." : "您的设置已更新。",
    "Settings have been updated." : "设置已更新。",
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "Activity notification for %s" : "%s 的动态通知",
    "Hello %s" : "%s 你好",
    "Hello %s," : "%s 你好，",
    "There was some activity at %s" : "在 %s 里有一些动态",
    "_and %n more _::_and %n more _" : ["更多 %n 项"],
    "Mail" : "邮件",
    "Stream" : "流",
    "This application enables users to view actions related to their files in Nextcloud." : "本应用可以让用户们查看和他们在Nextcloud上的文件相关的活动。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "本应用能够让用户查看与他们在Nextcloud中的文件相关的活动。\n\t\t一旦启用，用户将看到在他们的应用菜单中出现了一个名为”动态“的新图标.\n\t\t点击后会出现一个页面让用户跟踪文件的动态，包括新增文件、删除文件、移动、重命名、修改和共享。\n\t\t用户可以在个人的菜单中指定单独的动态设置。\n\t\t可以设置要记录的活动类型，以及是否用户看到自己的活动、\n\t\t是否只能在线查看、是否定期收到电子邮件摘要。\n\t\t 更多信息可以在动态文档中进行查看。",
    "Activity feed" : "活动订阅源",
    "Send activity emails" : "发送动态电子邮件",
    "Default settings" : "默认设置",
    "Configure the default activity settings for new users." : "为新用户设置默认的活动配置",
    "List your own actions in the stream" : "在流里面列出您自己的行为",
    "Notify about your own actions via email" : "通过邮件通知您自己的动态",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send emails:" : "发送电子邮件：",
    "As soon as possible" : "尽快",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "选择您想收到哪些活动的通知邮件，以及哪些活动在应用中显示。",
    "Choose which activities you want to see in your stream." : "选择您要在流中看到哪些活动。",
    "Settings" : "设置",
    "Enable RSS feed" : "启用 RSS 订阅源",
    "RSS feed" : "RSS 源",
    "No more events to load" : "已无更多事件",
    "\"remote user\"" : "远程用户",
    ", " : "，",
    "%s and %s" : "%s 和 %s",
    "Files" : "文件"
},
"nplurals=1; plural=0;");
